<?php
/**
 *	{$action_path}
 *
 *	@author		{$author}
 *	@package	{$project_id}
 *	@version	$Id: skel.action.php,v 1.7 2006/03/23 13:16:37 fujimoto Exp $
 */

/**
 *	{$action_name}եμ
 *
 *	@author		{$author}
 *	@access		public
 *	@package	{$project_id}
 */
class {$action_form} extends Ethna_ActionForm
{
	/**
	 *	@access	private
	 *	@var	array	ե
	 */
	var	$form = array(
		/*
		'sample' => array(
			'name'			=> 'ץ',		// ɽ̾
			'required'      => true,			// ɬܥץ(true/false)
			'min'           => null,			// Ǿ
			'max'           => null,			// 
			'regexp'        => null,			// ʸ(ɽ)
			'custom'        => null,			// ᥽åɤˤå
			'filter'        => null,			// Ѵե륿ץ
			'form_type'     => FORM_TYPE_TEXT,	// ե෿
			'type'          => VAR_TYPE_INT,	// ͷ
		),
		*/
	);
}

/**
 *	{$action_name}μ
 *
 *	@author		{$author}
 *	@access		public
 *	@package	{$project_id}
 */
class {$action_class} extends Ethna_ActionClass
{
	/**
	 *	{$action_name}
	 *
	 *	@access	public
	 *	@return	string		̾(ｪλʤnull, λʤfalse)
	 */
	function prepare()
	{
		return null;
	}

	/**
	 *	{$action_name}μ
	 *
	 *	@access	public
	 *	@return	string	̾
	 */
	function perform()
	{
		return '{$action_name}';
	}
}
?>
